@@ -34,6 +34,8 @@ tab-size = 4
 #include <chrono>
 #ifdef __APPLE__
 	#include <CoreFoundation/CoreFoundation.h>
+	#include <mach-o/dyld.h>
+	#include <limits.h>
 #endif
 
 #include <btop_shared.hpp>
@@ -44,12 +46,23 @@ tab-size = 4
 #include <btop_draw.hpp>
 #include <btop_menu.hpp>
 
-using std::string, std::string_view, std::vector, std::atomic, std::endl, std::cout, std::min, std::flush, std::endl;
-using std::string_literals::operator""s, std::to_string;
+using std::atomic;
+using std::cout;
+using std::endl;
+using std::endl;
+using std::flush;
+using std::min;
+using std::string;
+using std::string_view;
+using std::to_string;
+using std::vector;
+
 namespace fs = std::filesystem;
 namespace rng = std::ranges;
+
 using namespace Tools;
 using namespace std::chrono_literals;
+using namespace std::literals;
 
 namespace Global {
 	const vector<array<string, 2>> Banner_src = {
@@ -60,7 +73,7 @@ namespace Global {
 		{"#801414", "██████╔╝   ██║   ╚██████╔╝██║        ╚═╝    ╚═╝"},
 		{"#000000", "╚═════╝    ╚═╝    ╚═════╝ ╚═╝"},
 	};
-	const string Version = "1.2.7";
+	const string Version = "1.2.12";
 
 	int coreCount;
 	string overlay;
@@ -78,9 +91,9 @@ namespace Global {
 	string exit_error_msg;
 	atomic<bool> thread_exception (false);
 
-	bool debuginit = false;
-	bool debug = false;
-	bool utf_force = false;
+    bool debuginit{};   // defaults to false
+    bool debug{};       // defaults to false
+    bool utf_force{};   // defaults to false
 
 	uint64_t start_time;
 
@@ -90,8 +103,8 @@ namespace Global {
 	atomic<bool> should_sleep (false);
 	atomic<bool> _runner_started (false);
 
-	bool arg_tty = false;
-	bool arg_low_color = false;
+    bool arg_tty{};         // defaults to false
+    bool arg_low_color{};   // defaults to false
 	int arg_preset = -1;
 }
 
@@ -305,6 +318,7 @@ namespace Runner {
 	atomic<bool> stopping (false);
 	atomic<bool> waiting (false);
 	atomic<bool> redraw (false);
+	atomic<bool> coreNum_reset (false);
 
 	//* Setup semaphore for triggering thread to do work
 #if __GNUC__ < 11
@@ -326,8 +340,14 @@ namespace Runner {
 		pthread_mutex_t& pt_mutex;
 	public:
 		int status;
-		thread_lock(pthread_mutex_t& mtx) : pt_mutex(mtx) { pthread_mutex_init(&pt_mutex, NULL); status = pthread_mutex_lock(&pt_mutex); }
-		~thread_lock() { if (status == 0) pthread_mutex_unlock(&pt_mutex); }
+        thread_lock(pthread_mutex_t& mtx) : pt_mutex(mtx) {
+            pthread_mutex_init(&pt_mutex, NULL);
+            status = pthread_mutex_lock(&pt_mutex);
+        }
+        ~thread_lock() {
+            if (status == 0)
+                pthread_mutex_unlock(&pt_mutex);
+        }
 	};
 
 	//* Wrapper for raising priviliges when using SUID bit
@@ -335,16 +355,18 @@ namespace Runner {
 		int status = -1;
 	public:
 		gain_priv() {
-			if (Global::real_uid != Global::set_uid) this->status = seteuid(Global::set_uid);
+            if (Global::real_uid != Global::set_uid)
+                this->status = seteuid(Global::set_uid);
 		}
 		~gain_priv() {
-			if (status == 0) status = seteuid(Global::real_uid);
+            if (status == 0)
+                status = seteuid(Global::real_uid);
 		}
 	};
 
 	string output;
 	string empty_bg;
-	bool pause_output = false;
+    bool pause_output{}; // defaults to false
 	sigset_t mask;
 	pthread_t runner_id;
 	pthread_mutex_t mtx;
@@ -392,8 +414,7 @@ namespace Runner {
 	}
 
 	//? ------------------------------- Secondary thread: async launcher and drawing ----------------------------------
-	void * _runner(void * _) {
-		(void)_;
+    void * _runner(void *) {
 		//? Block some signals in this thread to avoid deadlock from any signal handlers trying to stop this thread
 		sigemptyset(&mask);
 		// sigaddset(&mask, SIGINT);
@@ -436,7 +457,9 @@ namespace Runner {
 
 			//! DEBUG stats
 			if (Global::debug) {
-				if (debug_bg.empty() or redraw) Runner::debug_bg = Draw::createBox(2, 2, 32, 8, "", true, "debug");
+                if (debug_bg.empty() or redraw)
+                    Runner::debug_bg = Draw::createBox(2, 2, 32, 8, "", true, "debug");
+
 				debug_times.clear();
 				debug_times["total"] = {0, 0};
 			}
@@ -453,6 +476,14 @@ namespace Runner {
 						//? Start collect
 						auto cpu = Cpu::collect(conf.no_update);
 
+						if (coreNum_reset) {
+							coreNum_reset = false;
+							Cpu::core_mapping = Cpu::get_core_mapping();
+							Global::resized = true;
+							Input::interrupt = true;
+							continue;
+						}
+
 						if (Global::debug) debug_timer("cpu", draw_begin);
 
 						//? Draw box
@@ -461,7 +492,7 @@ namespace Runner {
 						if (Global::debug) debug_timer("cpu", draw_done);
 					}
 					catch (const std::exception& e) {
-						throw std::runtime_error("Cpu:: -> " + (string)e.what());
+                        throw std::runtime_error("Cpu:: -> " + string{e.what()});
 					}
 				}
 
@@ -481,7 +512,7 @@ namespace Runner {
 						if (Global::debug) debug_timer("mem", draw_done);
 					}
 					catch (const std::exception& e) {
-						throw std::runtime_error("Mem:: -> " + (string)e.what());
+                        throw std::runtime_error("Mem:: -> " + string{e.what()});
 					}
 				}
 
@@ -501,7 +532,7 @@ namespace Runner {
 						if (Global::debug) debug_timer("net", draw_done);
 					}
 					catch (const std::exception& e) {
-						throw std::runtime_error("Net:: -> " + (string)e.what());
+                        throw std::runtime_error("Net:: -> " + string{e.what()});
 					}
 				}
 
@@ -521,12 +552,12 @@ namespace Runner {
 						if (Global::debug) debug_timer("proc", draw_done);
 					}
 					catch (const std::exception& e) {
-						throw std::runtime_error("Proc:: -> " + (string)e.what());
+                        throw std::runtime_error("Proc:: -> " + string{e.what()});
 					}
 				}
 			}
 			catch (const std::exception& e) {
-				Global::exit_error_msg = "Exception in runner thread -> " + (string)e.what();
+                Global::exit_error_msg = "Exception in runner thread -> " + string{e.what()};
 				Global::thread_exception = true;
 				Input::interrupt = true;
 				stopping = true;
@@ -582,7 +613,7 @@ namespace Runner {
 	//? ------------------------------------------ Secondary thread end -----------------------------------------------
 
 	//* Runs collect and draw in a secondary thread, unlocks and locks config to update cached values
-	void run(const string& box, const bool no_update, const bool force_redraw) {
+    void run(const string& box, bool no_update, bool force_redraw) {
 		atomic_wait_for(active, true, 5000);
 		if (active) {
 			Logger::error("Stall in Runner thread, restarting!");
@@ -699,10 +730,17 @@ int main(int argc, char **argv) {
 		}
 	}
 	//? Try to find global btop theme path relative to binary path
-#if defined(__linux__)
+#ifdef __linux__
 	{ 	std::error_code ec;
 		Global::self_path = fs::read_symlink("/proc/self/exe", ec).remove_filename();
 	}
+#elif __APPLE__
+	{
+		char buf [PATH_MAX];
+		uint32_t bufsize = PATH_MAX;
+		if(!_NSGetExecutablePath(buf, &bufsize))
+			Global::self_path = fs::path(buf).remove_filename();
+	}
 #endif
 	if (std::error_code ec; not Global::self_path.empty()) {
 		Theme::theme_dir = fs::canonical(Global::self_path / "../share/btop/themes", ec);
@@ -743,7 +781,7 @@ int main(int argc, char **argv) {
 	}
 	else {
 		string found;
-		bool set_failure = false;
+        bool set_failure{}; // defaults to false
 		for (const auto loc_env : array{"LANG", "LC_ALL"}) {
 			if (std::getenv(loc_env) != NULL and str_to_upper(s_replace((string)std::getenv(loc_env), "-", "")).ends_with("UTF8")) {
 				found = std::getenv(loc_env);
@@ -839,7 +877,7 @@ int main(int argc, char **argv) {
 		Shared::init();
 	}
 	catch (const std::exception& e) {
-		Global::exit_error_msg = "Exception in Shared::init() -> " + (string)e.what();
+        Global::exit_error_msg = "Exception in Shared::init() -> " + string{e.what()};
 		clean_quit(1);
 	}
 
@@ -951,7 +989,7 @@ int main(int argc, char **argv) {
 		}
 	}
 	catch (const std::exception& e) {
-		Global::exit_error_msg = "Exception in main loop -> " + (string)e.what();
+        Global::exit_error_msg = "Exception in main loop -> " + string{e.what()};
 		clean_quit(1);
 	}
 
